<?php
/*
Plugin Name: AutoGallery
Plugin URI: http://jeromeconus.ch/autogallery/
Description: Automatically adds an image gallery at the end of an article, made of all images found in the article.
Version: 0.1
Author: Jérôme Conus
Author URI: http://jeromeconus.ch
License: GPL2
*/


// Pour éviter une collision de nom
if( !function_exists("jc_auto_gallery")){

	// Ajout de notre fonction au crochet des filtres
	add_filter('the_content', 'jc_auto_gallery');

	function jc_auto_gallery($content){

		if( !is_page() ){
			// Si l'article renonce explicitement à une gallerie, on ne fait rien
			if (strpos($content,'[no-autogallery]')==true) {
				$content = str_replace("[no-autogallery]", "", $content);
				return $content;
			}
			
			// Si l'article contient déjà une gallerie, on n'en ajoute pas
			if (strpos($content,'[gallery')==true) {
				return $content;
			}
			
			$gallery = '<div class="jcgallerycontainer"><div class="jcgallerytext">Gallerie :</div></div>';
			// Recherche des images de l'article et extraction de l'id de chaque image
			preg_match_all('#<img.*src="(http://\S*)".*/>#', $content, $matches, PREG_SET_ORDER);
			
			$first = true;
			$gallery = $gallery."[gallery columns='8' ids='";
			
			foreach ($matches as $elem) {
				if (!$first) {
					$gallery = $gallery.",";
				} else {
					$first = false;
				}
				$image_id = get_attachment_id($elem[1]);
				if (!is_null($image_id)) {
					$gallery = $gallery.$image_id;
				}
				
			}
			$gallery = $gallery."']";
			
			// si aucune image n'est trouvée dans l'article, on n'ajoute pas de gallerie
			if ($first) {
				return $content;
			}
			return $content.$gallery;
		}
		return $content;
	}
}

if ( ! function_exists( 'get_attachment_id' ) ) {
    /**
     * Get the Attachment ID for a given image URL.
     *
     * @link   http://wordpress.stackexchange.com/a/7094
     *
     * @param  string $url
     *
     * @return boolean|integer
     */
    function get_attachment_id( $url ) {

        $dir = wp_upload_dir();

        // baseurl never has a trailing slash
        if ( false === strpos( $url, $dir['baseurl'] . '/' ) ) {
            // URL points to a place outside of upload directory
            return false;
        }

        $file  = basename( $url );
        $query = array(
            'post_type'  => 'attachment',
            'fields'     => 'ids',
            'meta_query' => array(
                array(
                    'value'   => $file,
                    'compare' => 'LIKE',
                ),
            )
        );

        $query['meta_query'][0]['key'] = '_wp_attached_file';

        // query attachments
        $ids = get_posts( $query );

        if ( ! empty( $ids ) ) {

            foreach ( $ids as $id ) {

                // first entry of returned array is the URL
                if ( $url === array_shift( wp_get_attachment_image_src( $id, 'full' ) ) )
                    return $id;
            }
        }

        $query['meta_query'][0]['key'] = '_wp_attachment_metadata';

        // query attachments again
        $ids = get_posts( $query );

        if ( empty( $ids) )
            return false;

        foreach ( $ids as $id ) {

            $meta = wp_get_attachment_metadata( $id );

            foreach ( $meta['sizes'] as $size => $values ) {

                if ( $values['file'] === $file && $url === array_shift( wp_get_attachment_image_src( $id, $size ) ) )
                    return $id;
            }
        }

        return false;
    }
}


// Chargement de la feuille de style spécifique à ce plugin
if ( ! function_exists( 'jcautogallery_add_my_stylesheet' ) ) {

	add_action( 'wp_enqueue_scripts', 'jcautogallery_add_my_stylesheet' );
	
	function jcautogallery_add_my_stylesheet() {
	    wp_register_style( 'autogallery-style', plugins_url('autogallery-style.css', __FILE__) );
	    wp_enqueue_style( 'autogallery-style' );
	}
}

?>
